
# jabor

Extra utilities tools to assist developers in django projects


## Installation

Install jabor

```bash
  pip install jabor
```
    
## Support

For support, email jabor@jabor.me


## Usage/Examples

```python
from jabor.utils import dateuntill

dateuntill(2020-08-01)
> 6 days
```

